#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commander = void 0;
const commander_1 = __importDefault(require("commander"));
exports.commander = commander_1.default;
const _1 = require(".");
commander_1.default.option("-p --path <path>", "Working path for serverless package context", process.cwd());
commander_1.default
    .command("show")
    .description("Show the serverless configuration for this package")
    .action(() => {
    const config = _1.getServerlessConfig(commander_1.default.path);
    process.stdout.write(JSON.stringify(config, null, 2));
});
commander_1.default
    .command("set <key> <value>")
    .description("Update a single key to a specific value")
    .option("-t --targetFile <filename>", "File to update - one of package.json or .serverlessrc", ".serverlessrc")
    .option("-j --json", "Treat value as JSON string", false)
    .action((key, value, { targetFile, json }) => {
    if (json)
        value = JSON.parse(value);
    _1.updateServerlessConfig({ [key]: value }, commander_1.default.path, targetFile);
});
const dep = commander_1.default
    .command("dependency")
    .description("Subcommands for dependency management");
dep
    .command("add <path>")
    .description("add a dependency")
    .action((path) => {
    const { name } = _1.getServerlessConfig(path);
    if (name) {
        const thisConfig = _1.getServerlessConfig(commander_1.default.path);
        thisConfig.dependencies[name] = path;
        _1.updateServerlessConfig({ dependencies: thisConfig.dependencies }, commander_1.default.path);
    }
    else {
        console.error("Could not add dependency at path", path, "because it is not a serverless package");
    }
});
dep
    .command("remove <name>")
    .description("remove a dependency")
    .action((name) => {
    const thisConfig = _1.getServerlessConfig(commander_1.default.path);
    delete thisConfig.dependencies[name];
    _1.updateServerlessConfig({ dependencies: thisConfig.dependencies }, commander_1.default.path);
});
commander_1.default.parse(process.argv);
//# sourceMappingURL=bin.js.map